summaryrefslogtreecommitdiff
path: root/zlib/inftrees.h
diff options
context:
space:
mode:
authorManolo Gouy <Manolo>2011-02-27 15:50:40 +0000
committerManolo Gouy <Manolo>2011-02-27 15:50:40 +0000
commit1f4e91b62267522c6f62bd78f6c9c077a0eca17a (patch)
treed40976004d7020c34c1d32e11187fccd7827cc9c /zlib/inftrees.h
parent5c29bca9d487f5e033a42f7066166907b8f87037 (diff)
Set zlib to version 1.2.5 as asked by STR #2508.
git-svn-id: file:///fltk/svn/fltk/branches/branch-1.3@8481 ea41ed52-d2ee-0310-a9c1-e6b18d33e121
Diffstat (limited to 'zlib/inftrees.h')
-rw-r--r--zlib/inftrees.h27
1 files changed, 17 insertions, 10 deletions
diff --git a/zlib/inftrees.h b/zlib/inftrees.h
index b1104c87e..baa53a0b1 100644
--- a/zlib/inftrees.h
+++ b/zlib/inftrees.h
@@ -1,5 +1,5 @@
/* inftrees.h -- header to use inftrees.c
- * Copyright (C) 1995-2005 Mark Adler
+ * Copyright (C) 1995-2005, 2010 Mark Adler
* For conditions of distribution and use, see copyright notice in zlib.h
*/
@@ -35,21 +35,28 @@ typedef struct {
01000000 - invalid code
*/
-/* Maximum size of dynamic tree. The maximum found in a long but non-
- exhaustive search was 1444 code structures (852 for length/literals
- and 592 for distances, the latter actually the result of an
- exhaustive search). The true maximum is not known, but the value
- below is more than safe. */
-#define ENOUGH 2048
-#define MAXD 592
+/* Maximum size of the dynamic table. The maximum number of code structures is
+ 1444, which is the sum of 852 for literal/length codes and 592 for distance
+ codes. These values were found by exhaustive searches using the program
+ examples/enough.c found in the zlib distribtution. The arguments to that
+ program are the number of symbols, the initial root table size, and the
+ maximum bit length of a code. "enough 286 9 15" for literal/length codes
+ returns returns 852, and "enough 30 6 15" for distance codes returns 592.
+ The initial root table size (9 or 6) is found in the fifth argument of the
+ inflate_table() calls in inflate.c and infback.c. If the root table size is
+ changed, then these maximum sizes would be need to be recalculated and
+ updated. */
+#define ENOUGH_LENS 852
+#define ENOUGH_DISTS 592
+#define ENOUGH (ENOUGH_LENS+ENOUGH_DISTS)
-/* Type of code to build for inftable() */
+/* Type of code to build for inflate_table() */
typedef enum {
CODES,
LENS,
DISTS
} codetype;
-extern int inflate_table OF((codetype type, unsigned short FAR *lens,
+int ZLIB_INTERNAL inflate_table OF((codetype type, unsigned short FAR *lens,
unsigned codes, code FAR * FAR *table,
unsigned FAR *bits, unsigned short FAR *work));